summaryrefslogtreecommitdiff
path: root/include/video.h
diff options
context:
space:
mode:
authorSimon Glass <sjg@chromium.org>2020-12-03 16:55:23 -0700
committerSimon Glass <sjg@chromium.org>2020-12-13 16:51:09 -0700
commit8a8d24bdf174851ebb8607f359d54b72e3283b97 (patch)
tree89fe2b9fd0c33209ce154170f9bda61f624dd9cd /include/video.h
parentb012ff1f1b0d662587dcf8707fe7cbf1c1f35d2f (diff)
downloadu-boot-8a8d24bdf174851ebb8607f359d54b72e3283b97.tar.gz
dm: treewide: Rename ..._platdata variables to just ..._plat
Try to maintain some consistency between these variables by using _plat as a suffix for them. Signed-off-by: Simon Glass <sjg@chromium.org>
Diffstat (limited to 'include/video.h')
-rw-r--r--include/video.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/video.h b/include/video.h
index 31a12bd799..7b7f62a827 100644
--- a/include/video.h
+++ b/include/video.h
@@ -18,7 +18,7 @@
struct udevice;
/**
* struct video_uc_platdata - uclass platform data for a video device
*
* This holds information that the uclass needs to know about each device. It
* is accessed using dev_get_uclass_plat(dev). See 'Theory of operation' at
@@ -31,7 +31,7 @@ struct udevice;
* @copy_base: Base address of a hardware copy of the frame buffer. See
* CONFIG_VIDEO_COPY.
*/
-struct video_uc_platdata {
+struct video_uc_plat {
uint align;
uint size;
ulong base;
@@ -77,7 +77,7 @@ enum video_log2_bpp {
* @fb: Frame buffer
* @fb_size: Frame buffer size
* @copy_fb: Copy of the frame buffer to keep up to date; see struct
- * video_uc_platdata
+ * video_uc_plat
* @line_length: Length of each frame buffer line, in bytes. This can be
* set by the driver, but if not, the uclass will set it after
* probing
@@ -18,7 +18,7 @@
struct udevice;
/**
- * struct video_uc_platdata - uclass platform data for a video device
+ * struct video_uc_plat - uclass platform data for a video device
*
* This holds information that the uclass needs to know about each device. It